# Release History
<br>

## 0.2.4 (2021-07-12)
---

- Amazon scraping item functionality added and more information is scraped from page
- IMDb running time regex pattern changed to 'm' instead of 'min'
- IMDb mediaviewer and trailer have now different URLs
- IMDb scrape_movie method takes name parameter and gets the first matching search result

## 0.2.3 (2021-29-11)
---

- IMDb scrape_movies method adjusted according to the new markup of imdb.com
- First edition of documentation completed

## 0.2.2 (2021-25-07)
---

- get_currency_ratio and get_word_info functions are added into helpers/helpers.py

## 0.2.1 (2021-03-04)
---

- Quick fix: Test lines removed

## 0.2.0 (2021-03-04)
---

- Methods are renamed
- Debugging lines are removed 
- Scraper properties return more data


## 0.0.4 (2021-31-03)
---

- Initial Release!
